package com.ruoyi.asset.service.impl;

import java.util.List;

import cn.hutool.core.util.StrUtil;
import com.baomidou.mybatisplus.extension.service.impl.ServiceImpl;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.stereotype.Service;
import com.ruoyi.asset.mapper.TbAssetMapper;
import com.ruoyi.asset.domain.TbAsset;
import com.ruoyi.asset.service.ITbAssetService;

/**
 * 资产信息Service业务层处理
 * 
 * @author 原动力
 * @date 2023-03-27
 */
@Service
public class TbAssetServiceImpl extends ServiceImpl<TbAssetMapper, TbAsset> implements ITbAssetService
{
    @Autowired
    private TbAssetMapper tbAssetMapper;

    /**
     * 查询资产信息
     * 
     * @param id 资产信息主键
     * @return 资产信息
     */
    @Override
    public TbAsset selectTbAssetById(Long id)
    {
        return tbAssetMapper.selectTbAssetById(id);
    }

    /**
     * 查询资产信息列表
     * 
     * @param tbAsset 资产信息
     * @return 资产信息
     */
    @Override
    public List<TbAsset> selectTbAssetList(TbAsset tbAsset)
    {
        return tbAssetMapper.selectTbAssetList(tbAsset);
    }

    /**
     * 新增资产信息
     * 
     * @param tbAsset 资产信息
     * @return 结果
     */
    @Override
    public int insertTbAsset(TbAsset tbAsset)
    {
        return tbAssetMapper.insertTbAsset(tbAsset);
    }

    /**
     * 修改资产信息
     * 
     * @param tbAsset 资产信息
     * @return 结果
     */
    @Override
    public int updateTbAsset(TbAsset tbAsset)
    {
        return tbAssetMapper.updateTbAsset(tbAsset);
    }

    /**
     * 批量删除资产信息
     * 
     * @param ids 需要删除的资产信息主键
     * @return 结果
     */
    @Override
    public int deleteTbAssetByIds(Long[] ids)
    {
        return tbAssetMapper.deleteTbAssetByIds(ids);
    }

    /**
     * 删除资产信息信息
     * 
     * @param id 资产信息主键
     * @return 结果
     */
    @Override
    public int deleteTbAssetById(Long id)
    {
        return tbAssetMapper.deleteTbAssetById(id);
    }

    /**
     * 根据条形码查询资产信息
     *
     * @param barCode 资产条形码
     * @return 资产信息
     */
    @Override
    public TbAsset selectTbAssetByBarCode(String barCode) {
        // 判断条形码是否为空
        if (StrUtil.isBlank(barCode)) {
            return null;
        }
        // 查询资产信息
        return query().eq("bar_code", barCode).one();
    }
}
